#
# spec file for package xmodmap
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%define UsrEtcMove 1
%endif
Name:           xmodmap
Version:        1.0.11
Release:        1.8
Summary:        Utility to modify keymaps and pointer button mappings in X
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        Xmodmap.template
Source2:        Xmodmap.remote.template
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
The xmodmap program is used to edit and display the keyboard modifier
map and keymap table that are used by client applications to convert
event keycodes into keysyms. It is usually run from the user's
session startup script to configure the keyboard according to personal
tastes.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install
%if 0%{?UsrEtcMove}
install -m0644 -D %{SOURCE1} %{buildroot}%{_distconfdir}/X11/Xmodmap
install -m0644 -D %{SOURCE2} %{buildroot}%{_distconfdir}/X11/Xmodmap.remote
%else
install -m0644 -D %{SOURCE1} %{buildroot}%{_sysconfdir}/X11/Xmodmap
install -m0644 -D %{SOURCE2} %{buildroot}%{_sysconfdir}/X11/Xmodmap.remote
%endif

%files
%license COPYING
%doc AUTHORS ChangeLog README.md
%if 0%{?UsrEtcMove}
%dir %{_distconfdir}/X11
%{_distconfdir}/X11/Xmodmap
%{_distconfdir}/X11/Xmodmap.remote
%else
%config %{_sysconfdir}/X11/Xmodmap
%config %{_sysconfdir}/X11/Xmodmap.remote
%endif
%{_bindir}/xmodmap
%{_mandir}/man1/xmodmap.1%{?ext_man}

%changelog
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.11
  * gitlab CI: add a basic build test
  * Build xz tarballs instead of bzip2
  * handle.c: avoid leaks when realloc() fails
  * PrintModifierMapping: stop leaking the map returned by
    XGetKeyboardMapping Fix warning about number of mouse buttons
* Sat Apr 17 2021 Dirk Müller <dmueller@suse.com>
- modernize spec-file (move license to licensedir)
* Wed Sep  9 2020 Stefan Dirsch <sndirsch@suse.com>
- reenabled move to /usr/etc/X11 for Tumbleweed (boo#1173053)
* Tue Sep  8 2020 Stefan Dirsch <sndirsch@suse.com>
- reverted move to /usr/etc/X11 for now (boo#1173053, comment#3)
* Sat Sep  5 2020 Stefan Dirsch <sndirsch@suse.com>
- moved Xmodmap files to /usr/etc/X11 (boo#1173053)
* Thu Feb 21 2019 sndirsch@suse.com
- Update to version 1.0.10
  * This release provides a man page update and some small build
    fixes & janitorial cleanups.
* Fri Apr 24 2015 sndirsch@suse.com
- Update to version 1.0.9:
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * Add -version option to print program version
  * Print which option was in error along with usage message
  * Avoid null pointer use if malloc() fails
  * Remove unneeded casts on malloc, realloc, and free calls
* Thu Sep 12 2013 zaitor@opensuse.org
- Update to version 1.0.8:
  + Add missing copyright dates from xmodmap.man to COPYING.
  + Allow printing -help & -grammar messages without a valid
    DISPLAY.
  + Error in manpage example about swapping Control_L/Caps_Lock
    keys (deb#641588).
  + Include X11/Xwindows.h on WIN32.
  + Include config.h before stdio.h & other system headers
    (fdo#48696).
- Drop xmodmap-includes.patch, fixed upstream.
* Mon Apr 23 2012 vuntz@opensuse.org
- Update to version 1.0.7:
  + Build fixes.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.0.6:
  + Replace chk_malloc + sprintf with asprintf.
  + Free copy of input line at end of process_line instead of
    leaking it.
  + Fix gcc -Wwrite-strings warnings.
  + Add missing _X_NORETURN to functions that need it.
  + Include strings.h for strcasecmp.
  + Improve error handling in copy_to_scratch.
  + Build system fixes.
- Add pkgconfig(xproto) BuildRequires: new dependency.
- Add xmodmap-includes.patch: Fix build: as asprintf is only
  defined when building as _GNU_SOURCE.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xmodmap from xorg-x11. Initial version: 1.0.5.
